@@ -527,6 +527,10 @@ void Output::apply(const OutputPtr& other)
         changes << &Output::rotationChanged;
         setRotation(other->d->rotation);
     }
+    if (d->scale != other->d->scale) {
+        changes << &Output::scaleChanged;
+        setScale(other->d->scale);
+    }
     if (d->currentMode != other->d->currentMode) {
         changes << &Output::currentModeIdChanged;
         setCurrentModeId(other->d->currentMode);
@@ -580,8 +584,9 @@ QDebug operator<<(QDebug dbg, const KScreen::OutputPtr &output)
                                   << output->name()
                                   << (output->isConnected() ? "connected" : "disconnected")
                                   << (output->isEnabled() ? "enabled" : "disabled")
-                                  << output->pos() << output->size()
-                                  << output->currentModeId()
+                                  << "pos:" << output->pos() << "res:" << output->size()
+                                  << "modeId:" << output->currentModeId()
+                                  << "scale:" << output->scale()
                                   << ")";
     } else {
         dbg << "KScreen::Output(NULL)";
